DimxPluginPlatform class abstract
The platform side of DimxPlugin: a method channel by default, a mock in tests.
- Inheritance
-
- Object
- PlatformInterface
- DimxPluginPlatform
- Implementers
Constructors
- DimxPluginPlatform()
- Constructs a DimxPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
initializeDimxSdk(
Map< String, dynamic> config) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showARScreen(
String url) → Future< void> -
showWebScreen(
String url) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DimxPluginPlatform
-
The default instance of DimxPluginPlatform to use.
getter/setter pair